package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````]"````````!``````````+B3````
M````!0```$``.``)`$``&0`8``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````A`````````"$``````````0`````````!````
M!0```````````````````````````````````&2+````````9(L`````````
M$`````````$````&````R(T```````#(G0```````,B=````````V`0`````
M````%0`````````0`````````@````8```#@C0```````."=````````X)T`
M```````@`@```````"`"````````"``````````$````!````%P"````````
M7`(```````!<`@```````$0`````````1``````````$`````````%#E=&0$
M````((L````````@BP```````""+````````%``````````4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````,B-````````R)T```````#(G0``
M`````#@"````````.`(````````!`````````"]L:6(O;&0M;&EN=7@M<FES
M8W8V-"UL<#8T9"YS;RXQ``````0````4`````P```$=.50`<OM<ZH'-TFY@+
M?J(RFPX\(ZI]JP0````0`````0```$=.50``````!`````\`````````$0``
M`$L````$````"````""0$`$%0`3$*`(!!("&!(2""0``"2`$"(B@$$6Z``*(
M`````$L```!.````40```%(```!9````6@```%P```!>````8````&(```!D
M````9@```&<```!I``````````````!NQ=\?SMY'+6M_FGPNQ9NV(/_D#M5D
MU'S9<5@<XD?&`4+ZUX>L2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QF&7X*
MAT)%U>R)!W#3#!3BGG-0G]C:S>.>,V+;[3[/TFP5C"7,##J7"_]A\F%_J9R;
MX*<""FL:GE"CX/M)``````````````````````````````````````,`#`!0
M'P``````````````````\`(``!(`````````````````````````$0```"``
M````````````````````````4`(``!(`````````````````````````I0``
M`!(`````````````````````````FP$``!(`````````````````````````
M=`$``!(`````````````````````````!@,``!(`````````````````````
M````>0(``!(`````````````````````````*`,``!$`````````````````
M````````%`,``!(`````````````````````````<P(``!(`````````````
M````````````=0```!(`````````````````````````G`(``!(`````````
M````````````````XP$``!(`````````````````````````_0```!(`````
M````````````````````\@```!$`````````````````````````SP$``!(`
M````````````````````````UP(``!(`````````````````````````ZP$`
M`!(`````````````````````````6`$``!(`````````````````````````
MU````!$`````````````````````````T`(``!(`````````````````````
M````)@$``!(`````````````````````````'`(``!(`````````````````
M````````QP(``!(`````````````````````````LP```!(`````````````
M````````````H@$``!(`````````````````````````_@(``!(`````````
M````````````````$P(``!(`````````````````````````AP(``!(`````
M````````````````````CP$``!(`````````````````````````7@(``!(`
M````````````````````````Q`$``!(`````````````````````````0@(`
M`!(`````````````````````````7@,``!$`````````````````````````
M-`$``!(`````````````````````````P`(``!(`````````````````````
M````IP(``!(`````````````````````````50```!(`````````````````
M````````)P,``"$`````````````````````````+0(``!(`````````````
M````````````R0$``!(`````````````````````````A````!(`````````
M````````````````-`(``!(`````````````````````````D````!(`````
M````````````````````30$``!(`````````````````````````$P$``!(`
M````````````````````````1P```!(`````````````````````````!P$`
M`!(`````````````````````````20(``!(`````````````````````````
MA`$``!(`````````````````````````X0```!(`````````````````````
M````"P(``!(`````````````````````````C@(``!(`````````````````
M````````;`(``!(`````````````````````````KP(``!(`````````````
M````````````!@(``!(`````````````````````````9@$``!(`````````
M````````````````9````!(`````````````````````````N0(``!$`````
M````````````````````,`,``!(`````````````````````````Q0```!(`
M````````````````````````1`$``!(`````````````````````````X0(`
M`"(`````````````````````````)@,``!$`````````````````````````
M+0```"``````````````````````````5P(``!(`````````````````````
M````HP,``!(`````````````````````````.@(``!(`````````````````
M````````O0$``!(`````````````````````````#0,``!(`````````````
M````````````90(``!(``````````````````````````@$``!(`````````
M````````````````N`,``!(`#`!"-@```````&```````````P0``!(`#`!&
M+0````````P&````````(0,``!(`#`!0'P```````*0!````````@`,``!(`
M#``6*`````````(`````````J00``!(`#``8*````````,`!````````WP0`
M`!(`#`!2,P```````/`"````````E00``!``%@"@H@``````````````````
MZ@,``!(`#`#8*0```````!X`````````$`0``!(`#`#420```````-H`````
M````*`0``!$`#0"@3`````````0`````````9P0``!``%@#(L@``````````
M````````H00``!(`#`#B)@```````#(`````````M@0``!(`#`"J+```````
M`)P`````````R`0``!(`#``R+````````&``````````&P0``!``%```H```
M````````````````]P,``!(`#`#V*0```````,(`````````;`0``!``\?^@
MJ@``````````````````Q`,``!``%0"@H@``````````````````700``!$`
M%`!`H`````````@`````````<`,``!(`#`"23`````````(`````````RP,`
M`!``%0"@H@``````````````````300``!(`#``Z3````````%@`````````
M(00``!(`#`#T(````````"X`````````VP,``!``%```H```````````````
M````U@0``!(`#`"`20```````%0`````````'00``"``%```H```````````
M````````K`,``!``%@#(L@``````````````````D0,``!(`#`"2+```````
M`!@`````````-P0``!(`#`!8)P```````+X`````````BP0``!(`#`"N2@``
M`````(P!````````?@0``!(`#`"X*@```````'H!`````````&QI8G!E<FPN
M<V\N-2XS,`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S
M`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`
M4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P
M=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=8
M4U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`
M<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T
M8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`&-L
M;W-E`'!T:')E861?9V5T<W!E8VEF:6,`;'-E96LV-`!?7V5R<FYO7VQO8V%T
M:6]N`&QI8F,N<V\N-@!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C
M:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T
M<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I
M;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD
M:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R
M96=I<W1E<E]A=&9O<FL`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS;RXQ`%]?
M<W1A8VM?8VAK7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E
M>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`%]?0E-37T5.1%]?`'!A
M<E]C;&5A;G5P`%]E9&%T80!?7U-$051!7T)%1TE.7U\`7U]$051!7T)%1TE.
M7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?
M=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?
M9VQO8F%L7W!O:6YT97(D`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?
M<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`
M1TQ)0D-?,BXR-P```````@````(````"`````@`"``(``@`"`````@`#````
M```#``(``P```````@````(``@```````@`"``(````"``,``@`$`````@`"
M`````@`"``,````"```````````````"```````"``(``@`"``(```````(`
M`@```````@`"`````@`"``(``P`"``(``@`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!````
M```!``$`0@,``!`````@````AY&6!@``!`#U!`````````$``0"M`0``$```
M`"````"'D98&```#`/4$`````````0`!`/P!```0`````````(>1E@8```(`
M]00```````#(G0````````,`````````(B$```````#0G0````````,`````
M````O"$```````#8G0````````,`````````@B$`````````H`````````,`
M`````````*`````````0H`````````,`````````J$P````````8H```````
M``,`````````N$P````````@H`````````,`````````P$P````````HH```
M``````,`````````R$P````````PH`````````,`````````T$P```````!`
MH`````````,`````````>%````````!XH@````````,`````````4!\`````
M``!`H@````````(````#``````````````!(H@````````(````'````````
M``````!0H@````````(````*``````````````!8H@````````(````1````
M``````````!@H@````````(````6``````````````!HH@````````(````D
M``````````````!PH@````````(````P``````````````"`H@````````(`
M```\``````````````"(H@````````(````]``````````````"0H@``````
M``(```!!``````````````"8H@````````(```!#``````````````!8H```
M``````4````"``````````````!@H`````````4````$``````````````!H
MH`````````4````%``````````````!PH`````````4````&````````````
M``!XH`````````4````(``````````````"`H`````````4````)````````
M``````"(H`````````4````+``````````````"0H`````````4````,````
M``````````"8H`````````4````-``````````````"@H`````````4````.
M``````````````"HH`````````4````/``````````````"PH`````````4`
M```0``````````````"XH`````````4````2``````````````#`H```````
M``4````3``````````````#(H`````````4````4``````````````#0H```
M``````4````5``````````````#8H`````````4````7``````````````#@
MH`````````4````8``````````````#HH`````````4````9````````````
M``#PH`````````4````:``````````````#XH`````````4````;````````
M````````H0````````4````<```````````````(H0````````4````=````
M```````````0H0````````4````>```````````````8H0````````4````?
M```````````````@H0````````4````@```````````````HH0````````4`
M```A```````````````PH0````````4````B```````````````XH0``````
M``4````C``````````````!`H0````````4````E``````````````!(H0``
M``````4````F``````````````!0H0````````4````G``````````````!8
MH0````````4````H``````````````!@H0````````4````J````````````
M``!HH0````````4````K``````````````!PH0````````4````L````````
M``````!XH0````````4````M``````````````"`H0````````4````N````
M``````````"(H0````````4````O``````````````"0H0````````4````Q
M``````````````"8H0````````4````R``````````````"@H0````````4`
M```S``````````````"HH0````````4````T``````````````"PH0``````
M``4````U``````````````"XH0````````4````V``````````````#`H0``
M``````4````W``````````````#(H0````````4````X``````````````#0
MH0````````4````Y``````````````#8H0````````4````Z````````````
M``#@H0````````4````[``````````````#HH0````````4````^````````
M``````#PH0````````4````_``````````````#XH0````````4```!`````
M````````````H@````````4```!$```````````````(H@````````4```!%
M```````````````0H@````````4```!&```````````````8H@````````4`
M``!'```````````````@H@````````4```!(```````````````HH@``````
M``4```!)```````````````PH@````````4```!*````````````````````
M`````)>#```S`\-!`[Z#31,#0_V3@H--$U,3`(.R@@!G``X`%XX```,^CDQG
M`PX`$P```!>.```#/@Y,9P,.`!,````7C@```SZ.2V<##@`3````%XX```,^
M#DMG`PX`$P```!>.```#/HY*9P,.`!,````7C@```SX.2F<##@`3````%XX`
M``,^CDEG`PX`$P```!>.```#/@Y)9P,.`!,````7C@```SZ.2&<##@`3````
M%XX```,^#DAG`PX`$P```!>.```#/HY'9P,.`!,````7C@```SX.1V<##@`3
M````%XX```,^CD9G`PX`$P```!>.```#/@Y&9P,.`!,````7C@```SZ.16<#
M#@`3````%XX```,^#D5G`PX`$P```!>.```#/HY$9P,.`!,````7C@```SX.
M1&<##@`3````%XX```,^CD-G`PX`$P```!>.```#/@Y#9P,.`!,````7C@``
M`SZ.0F<##@`3````%XX```,^#D)G`PX`$P```!>.```#/HY!9P,.`!,````7
MC@```SX.06<##@`3````%XX```,^CD!G`PX`$P```!>.```#/@Y`9P,.`!,`
M```7C@```SZ./V<##@`3````%XX```,^#C]G`PX`$P```!>.```#/HX^9P,.
M`!,````7C@```SX./F<##@`3````%XX```,^CCUG`PX`$P```!>.```#/@X]
M9P,.`!,````7C@```SZ./&<##@`3````%XX```,^#CQG`PX`$P```!>.```#
M/HX[9P,.`!,````7C@```SX..V<##@`3````%XX```,^CCIG`PX`$P```!>.
M```#/@XZ9P,.`!,````7C@```SZ..6<##@`3````%XX```,^#CEG`PX`$P``
M`!>.```#/HXX9P,.`!,````7C@```SX..&<##@`3````%XX```,^CC=G`PX`
M$P```!>.```#/@XW9P,.`!,````7C@```SZ.-F<##@`3````%XX```,^#C9G
M`PX`$P```!>.```#/HXU9P,.`!,````7C@```SX.-6<##@`3````%XX```,^
MCC1G`PX`$P```!>.```#/@XT9P,.`!,````7C@```SZ.,V<##@`3````%XX`
M``,^#C-G`PX`$P```!>.```#/HXR9P,.`!,````7C@```SX.,F<##@`3````
M%XX```,^CC%G`PX`$P```!>.```#/@XQ9P,.`!,````7C@```SZ.,&<##@`3
M````%XX```,^#C!G`PX`$P```!>.```#/HXO9P,.`!,````7C@```SX.+V<#
M#@`3````'7&FY)>$``"#M$0QG&`JAR[H,N0,"#``:`@^](;L.LZBZ,K@3OSO
M\+_A%X8```,V9B^RA1>%```#-<4O[R"04)>'``"#MP<M@\<'`&.,!PX7A```
M$P2$,!>)```#.0DK`R4)`._PW\D#1Z5+JH<#)0D`$V<G`".-YTKO\'_(`T>E
M2_)'$V<7`)4G(PWE2A.5-P#O\/_3PF5R1@CDG&&JAIL(1@`<X9<W``"3AR<'
M'.67AP``@[<'!!SIES<``).'9P8<[9%'7,"%1V/0QP*A!1N("`"51XAA$Y<W
M`#:7(SRG_H4GH07C&/C^"&R."+:8`4<-)I<%``"3A05M([P(_N_P']XJB37%
M"&R3"4$"[_`_PLZ%%S4``!,%1=;O`"`5,<T(;._PW[SO\)_8(G><8&,5]P;F
M8$9DIF3B>4J%!FDE88*`[_#?Q!>$```3!`0A".PQQ>_PW[87B0```SD)&P,E
M"0#O\-^YA6<^E:,(!:3%O0AL[_#?X"J)>;<(:`'%[Q`@5WF_SH47-0``$P6%
MQ^\`X`T(Z%'5Y;?O\'^\!47O\!_:[P#@`JJ'%X4```,UY1>"93``$W$!_Y<V
M``"3A@:S%S<``!,'![@*B._P7ZT"D)>1``"3@>&7@H```!>%```3!:7QEX<`
M`).')_%CB:<`%X,```,SXP]C`P,``H."@!>%```3!67OEX<``).'Y^Z)CQ/7
M-T"3U?<#NI6%A8')%X,```,S8Q)C`P,``H."@$$1(N`7A```$P2D$8-'!``&
MY(7CEX<``(.WIP^1QQ>%```#-07F@I?O\%_XA4<C`/0`HF`"9$$!@H!9OSEQ
M!OPB^";T2O!.[%+H5N1:X$G!EX<``(.WYP<#NP<`8PH+!H-'!0"JB2Z**HD3
M!]`#O<-CAN<`@T<9``4)_?L["3E!`S0+`!W`VH23"M`#(H5*ALZ%[_#?P[,'
M)`$)Y8/'!P!C@%<#@&2A!'7PXG`BA4)THG0">>)I0FJB:@)K(6&"@+.$9$&-
MA`4)(R":`$J4\;\!1.&_`4EMMSEQ3NR7B0``@[FI`(.W"0`B^";T2O`&_"J$
M/N1$`!>)```#.8G]IH4BA>_PO_,5P1)'@S<)``X'NI>89YCC9=>8:Z$'F.-M
M_Z:%(H7O\)_Q9?$B9X.W"0!C&?<`XG!"=*)T`GGB:2%A@H#O\-^>'7&BZ*;D
M3OQ2^(;LRN!6]%KP7NQBZ(/'!0"7B0``@[EI^`.W"0"3AS?\D[<7`#.$]0"J
MA"*%.N3O\!^C*HI,`":%[_!?ZW7!*HGO\/^A8WI%"Q))EXH``(.Z2O,3&SD`
M`\<$`*:'DP;0`V,+!Q)C!M<``\<7`(4'??N%GP.Y"@`3!2H`/I5:F>_P'X<C
M,*D`8P8%$))&@[<*``/'!`".!K:7G&,3A10`$P;0`R.`YP`!Z\VH`T<%``4%
M(X#G`"W#OH:%!^,8Q_X3!]`#(X#F``-'!`"%!P4$HX_G_G7[`44B9X.W"0!C
M%?<,YF!&9*9D!FGB>4)ZHGH">^)K0FPE88*`@T<$``4)!02C#_G^X=N#1P0`
M!0D%!*,/^?[]\\&W$X<F`+Z&NH=%MY>*``"#NNKE`[P*`(,W#`"ER^*'`4F8
M9\J&H0<%*67_C2:3E38`EX<``).'!^F80P7K!4<NA9C#[_!O^:J+%<D3&SD`
M6H;BA>_P?XLCL'H!DP<9`(X'OILCL`L`2L+AO6*%[_#?JB.PJ@"JBQ,;.0!E
M\7U5B;>!1^F]OH:%!P6WP44!24VW[_"?@U%QSN67B0``@[F)WH.W"0"&]:+Q
MINW*Z=+A5OU:^5[U8O%F[3[E"<6#1P4`*H2=XRIG@[<)`&,1]PZN<`YT[F1.
M::YI#FKJ>DI[JGL*?.IL;6&"@._P'XNJA'G9$PK@`A<[```3"\N`DPJ!`#UL
MD6LFA>_P+_<]Q8-'-0&3##4!8XE'!X-'-0%CC$<'(H7O\'^"*HEFA>_P_X$[
M!:D`"27O\$_JYH<BA]J&?5:%12J)[_!/YE:&RH4!1>_POY3]5V,(]0#B1[/W
MAP&!)V."=P5*A>_P/X5*A>_PWYXFA>_P;_!9^2:%[_#O^2*%[_"/Z8&W@\<<
M`*W?@T<U`>.81_F#QQP`XY1'^8/'+`"UT[V_2H7O\/_NP;?O\,_Q<7$F[9>$
M``"#M,3,G&`B\:J%*H0P``%%!O4^Y>_PS^8-X>)'O6819_6/8X7G`"EG8YKG
M`(E%(H7O\`_@$S45`!&@`44J9YQ@8Q?W`*IP"G3J9$UA@H#O\"_L77%6['US
MA6JBX";\2OA.](;D4O`7B0```SDIQAJ1_7>3A@H!`S<)`.$7BI8%9*Z)LX7V
M`).'B@"*EZJ$$P;T_Q<E```3!>5KF./O\$_HFP<%`&-?\`83APH!"I<S!(=`
M&XKW_U*4`T>$_Y>&``"#ML:_@ZH&`#GK8P(*!H5G?73!!V$4BI<^E%*&DP7P
M`B*%[_#O["'%5H7O\&_<TH8BAJ:%[_#?@H5GH0>*EYAC@S<)`&,=]P(%8QJ1
MIF`&9.)T0GFB>0)ZXFIA88*`/HI]MY>'``"#MV>Y@ZH'`%:%[_`/V$Z&IH7O
M\(_<=;_O\"_=01$&Y)>'``"#MR>WB$/O\`_6HF"79@``DX:F/A>&```#-J:T
MER4``).%I5]!`6_P#^Y!$2+@%X0```,T!+0(0`;D[_#/TN_PO_L(0._P+]("
M9*)@%S<``!,'IY*!1[J&%Q8``!,&!L&7)0``DX5E74$!;_#/[EUQ3O27B0``
M@[G)L%+P>7.#MPD`"6J&Y*+@)OQ*^!,'B@$:D0J7'./O\`_J>723!PH"BI<A
M%#Z4!68JAY<G``"3AT=:ER8``).&1EH%!H5%(H7O\&^^_723!PH"BI?!%+Z4
M!6:FA2*%[_`/T),7!0(!26/!!P(;!`4`&P44`._PK[XJB0')(H:FA4J4[_#/
MTB,`!`")9^$'BI>88X.W"0!C'?<`"6,:D:9@2H4&9.)T0GFB>0)Z86&"@._P
M[\F)MU%Q!69]<Z+QINW*Z<[E7O6&]=+A5OU:^6+Q9NV3!P8)&I&7BP``@[OK
MHOUY`[<+`).&2?>*ERZ)LX77`),'A@BJA(J7%R4``!,%14^8X^_PGY4JA),%
M\`(FA>_P[\$IP::%%R4``!,%94[O\'^D)H6%9Y.'APB*EYAC@[<+`&,?]Q(%
M8QJ1KG`.=.YD3FFN:0YJZGI*>ZI["GSJ;&UA@H`FA>_P;\<JBI<E``"3A05+
M2H7O\&_A`2JJC%W1A6<3AP<)$XF)_PJ7.ID3AP<)@\<,``J7A6J3B8GW%RP`
M`!,,;#ZZF3,+5T')SQ'$YH4BA>_PC^$UR6:%[_`/PIL'!0`SA_P`@T;W_Q,'
M\`)CG>8`$P;P`OTWLX;\``/']O\C@`8`XPG'_AL%&@"IG^/:5_,%9H5%)HB7
M)P``DX>G0F:'ER8``).&AD)*A>_P[Z).ALJ%`47O\$_1`>F#)XOXO68A9_6/
M8XSG`I<E``"3A04_`47O\&_5JHSC!`7N@\<,`*WW$<2#1P0`FX<G_8''XHR%
M1U&_@T<4`.';U;^%14J%[_"/H7'QRH47)0``$P4%.N_P'Y!*A>_P+YU=O>_P
MSZT#1P4`JH<9RY,&\`*%!V,3UP`^A0/'!P!U^X*`@H!=R4$1(N`&Y(-'!0`J
MA-G+[_"OLA,&]?\BEA,'\`)C9L0`K:!]%F,%Q`:#1P8`XXOG_A,'\`)C>\0$
M?19C"L0$@T<&`..;Y_X3!_`"*:"#1P8`8Y7G`'T6XVO$_@&.$P<F`(5G`45C
M[^<`A68%!J*%%X4``!,%)8;O\"^_%X4``!,%986B8`)D00&"@.,>Q/H#1P8`
MDP?P`A<E```3!:4N8Q;W`!<E```3!>4C`F2B8$$!;_"/CQ<E```3!<4B;_#/
MCAUQEV<``).'9P*FY)=T``"#M$1ZC&N0;Y1SF'<#N`0`@]<'`Q<E```3!<4J
MANPNZ$+\,NPV\#KT(QCQ`J+H[_!/]A<E```3!>4I[_"/]1<E```3!:4I[_#/
M]!<E```3!>4I[_`/]!<E```3!:4I[_!/\Q<E```3!>4I[_"/\A<E```3!:4A
M[_#/\1<E```3!64I[_`/\1<E```3!:4I[_!/\!<E```3!>4I[_"/[Q<E```3
M!:4?[_#/[F``HH47)0``$P4E*>_P#^0!R:J%%R4``!,%)2;O\*_SHH47)0``
M$P7%*._P+^*JA1G%%R4``!,%11#O\,_QHH47)0``$P5E*._P3^"JA17)%R4`
M`!,%Y1CO\._OER4``).%)2H7)0``$P4E'N_PK^YB=YQ@8Q3W!.9@1F2F9"5A
M@H"BA1<E```3!24E[_`/W*J%`<D7)0``$P4E'>_PK^MUORE&ER4``).%I203
M!1$"[_#OHD7UDP6Q`NF_[_`OB'EQ(O`7=````S0D8QQ@)NR7=```DX1D/(A`
M/N0&]/U78POU`")G'&!C&O<"HG`"=.)D16&"@$P`%R4``!,%Y1;O\,_4JH<!
M18'+@\<'`(G'$X4'_3,UH`"(P.FW[_`O@D$1!N3O\*^-`27O\$^E$<$(8:)@
M00&"@#EQ2O`7>0```SFI6X,W"0`F]$P`JH07)0``$P6%&P;\(OA.[#[D[_#O
MSJ:%"<6#1P4`*H2=XQ<E```3!849[_`/WB)G@S<)`&,8]P3B<$)THG0">>)I
M(6&"@._PSY9U\2:%[_!/@JJ)(H7O\,^!3I4)!>_@7^J%12*(ER<``).'QP0F
MAY<F``"3AB8%?5:JB>_@?^7.A46W[^#_]B5QSOZ7>0``@[GI42+KEW<``).'
M1RL#O@D`87,A9";G2N,&[]+ZUO;:\M[NXNJ8>QJ1DP0$%1,$A!0#LX<`@[@'
M`0.XAP&0<Y1WBI3A=PJ4DX7'[",PQ`&FEQ<N```3#HX/*HDCN,?M([3G\A<N
M```3#F[R%R<``!,'9PZFE1<E```3!<7X([S'[2.P!^XCL&?P([07\2.X!_$C
MO,?P([#7\B.XY^XCO`?N[_#OO!'%@T<%`"J$8Y('.N_P/^DJA&,&!3`BA>_@
M7_(&!04%[^#?V@-'!``JB@W#TH27*@``DXKJ"":%UH9]5H5%!03OX-_5`T<$
M`(D$=?<A9^%ZDP<'%9.$"O"*E[Z4DP<'%9.*RNR*EQ<E```3!>7DOIHIH(AD
MH01C!@4.UH7O\.^T*H1EV8-'!0#MU^_PK_%UT2*%[^"_T2J$:<4BA>_@'^JJ
MA%*%[^"?Z:F<FX1$0":%[^#?T=*(ER<``).'Y^P7*```$PAH`"*'ER8``).&
M1@!]5H5%*HKOX'_,DP4`'%*%[^#?[_U78QCU`._@/]D<045'8YSG*"%KX7J3
M!PL5BI<3A@KS/I;2A0%%[^`_TBJ$6<V7=P``@[<G.(,V"0"(8U*'%R8``!,&
MIO^%1>_@'\R!1*%GDX>'%(J7F&.#MPD`8QWW0"%C&I'Z8":%6F2Z9!II]GE6
M>K9Z%GOV:U9L'6&"@*%GDX<'%>%ZBI>^F@.T"NV!1#F@DY<T`-:7`[0'[0W$
M@T<$`)7#(H7O\*_AA21]T2*%[^"?P2J$XQ`%\).7-`#6EP.T!^UI_`%$_;63
M!PL5BI<SBU<!@R<+]+UF$6?UC^.8Y_2#*XOT[^`_VYL'!0#CD/OT@R<+]!,'
M`!R3]_<?XYCG\B:%[^!?OJ%GDX<'%9.%RNR*EZJ$OI47)0``$P6%]^_P;YQC
M"04:@SH)`._@W[FJA5:%[_#?@"J+8PX%&%J%[^"?T9L*!0"-1V/85P,3A<K_
MER4``).%9?1:E>_@W^X)[9%'8XWZ)IN'RO_:EP/']_^3!_`"8P3W)N_P'[X!
MZ8%%6H7OX%_K*HEC&044ER4``).%I>`7)0``$P6EUN_P+Z7OX'_:*HB7*```
MDX@(_I<G``"3AP?/4H>7)@``DX;F[WU6A44FA>_@'Z]]6<5*%RP``!,,C/N7
M*P``DXN+S!<K```3"XON):#OX/^Z'$%CEU<#[^!?U04D*HABX**(WH=2A]J&
M?5:%12:%[^#?JI,%`!PFA>_@/\[C""7]4H7OX)_DIH47)0``$P4EQ>_P+YPF
MA>_P_[D9O2%G87J3!P<5DPK*[(J7OIJ3!P<5BI>!1!<E```3!>75/IHYH).7
M-`#2EP.UA^X%Q=:%[_"OAX4D==6#1P4`_=/OX/^D*H3C&07*DY<T`-*7`[6'
M[G']-47OX'^E*HH7)```$P0$TA,',`55L1=W```#-Z<0"&.#-@D`4H<7)@``
M$P8FU(5%[^"?I(%$8;/O\+^P(H7OX+^?JH2MNP,["0"5M0E&N57OX)^G(6MA
M=),'"Q6*EY,*A/^^FAE&UH5*A>_@_[:3!PL5BI>BEP/'A_\9YP/'E_^3!C`$
M8PO7#@%&@45*A>_@OZ/O$&!XH6=A=).'!Q63"H3_BI<JB[Z:*:#6A5J%[Q#@
M>R%FUH5*A>_@'[(;!@4`XT7`_DJ%[^`_N*%JDX<*%8J7$PD$^SZ9VH5*A>\0
ML`:3APH5$P2$_(J7/I03"X0"ERH``).*BL4#1PD`(H76AGU6A44)!._@/Y(%
M">,6B_ZA9N%W$X<&%0J7$XB'_#,#]P`ZF)<H``"3B$C=ER<``).'1ZY2AY<F
M``"3AB;.?5:%12:%(P@#_N_@'XZ)M0,YB0#C#`G82H7OX!^GC4?C]J?8<167
M)0``DX7%RDJ5[^"_Q.,<!=9*BXV[`\:G_Y,&$`3C$];P@\:W_^.?YNZ#QL?_
M$P>`!..9YNX#Q]?_DP=0!.,3]^X)1I,%8/Q*A>_@OY'6A1,&D`)*A>_@_Z&7
M*```DXBHTU:(ER<``).'AZ12AY<F``"3AF;$?5:%12:%[^"?A&VS[^`_EAEQ
MSNQJ\)=Y``"#N0GP%WT```,]C?"#-PT``Z4)`(;\HOAF]#[DIO3*\-+HUN3:
MX%[\8OAN[._@GXPJA`.E"0"3#$$`[^"_BP-'A`NJA^:%%R4``!,%9:&CC.<*
M[^`?X1G%`T<%`),'$`-C!?<B[_"/[P.E"0#OX)^(K48%1I<E``"3A86^[^"?
MF&,.!1Z7>@``DXJ*[!1I`Z=*`(5'`[N&`H.D"0!CU><(MPL@``%*!4F3BPM`
M$PP`0"&H#&INA>_@_["#ITH`)>$%*04J8UWY!":%[^"_@H%&4H;:A>_@'Z<J
MA&,-!1H088.VB@`3%SD`7$8VEX,]!P"S]_L`@Z0)`..-A_LFA>_@;_\,8(E&
M`4;OX-^&JH5NA>_@7ZN#I`D`@Z=*`%71&X?W_V,-1Q$FA>_@S_R-1@5&ER4`
M`).%1;/OX-^,*H0%Q0.E"0#OX`_['&@7)@``$P8FLHQC[^`/_QQHG&/<1Q.7
MEP)C3`<4`Z4)`._@K_B-1@5&ER4``).%);#OX+^(*H0%Q>:%%R4``!,%!8CO
MX'_-JH0#I0D`8X@$$._@K_4<:":&C&/OX`_Z`Z4)`._@C_0JA`.E"0#OX._S
M!4:7)0``DX4%K._@'XJJA1<F```3!J:L(H7OX`_W`Z4)`._@C_&C#`4*YH47
M)0``$P7E@._@7\<CN*H`*H0EQ9,%`!PBA>_@7X?%1V,']0";!Q4`!4=C8/<,
M(F>#-PT`8QGW"N9P1G2F=`9YYFE&:J9J!FOB>T)\HGP"?>)M"6&"@`5'XU3W
M[@5$)H7OX._JVH7OX(_@@Z=*``4D@Z0)`.-%]/[AM0.UB@#O\&_X([BJ`"J$
M4?47)0``$P7%HN_@WX"#I`D`EWH``).*RLQYO8-'%0#CC0?<R;N#ITH`@Z0)
M`!N']__C$T?I8;_OX._D`[>*`!QH#&.(8^_@/_[%O0.E"0#OX&_C'&B,8^_@
M[_YQO>_@C^B#MXH`JH8BAHQC%R4``!,%I9[OX"_Z`1$BZ";D!NRJA._PK[J#
M1P4`*H21RQ,'\`(%!6.3YP`JA(-'!0#U^^_PC]P1S8G,@\<$`)'+$4:7)0``
MDX7E@R*%[^#/_!'%XF!"9*)D!6&"@$)DXF`FA:)D!6%OX/_=$P$!TR,T$2PC
M,($L(SR1*B,X(2LC-#$K(S!!*R,\42DC.&$IEW@``(.X*+J#MP@`.`#]7T%O
M(S3Q*!,#A0.3`X4'.HB3WP\"MP+_`!,/#_`#-@,`00@A`Y-5!@*3%H8!$Q2&
M`)-7A@*37H8`DU2&`Q.>A0&S]O8!,W14`+/WYP'!CK/^[@'%CS-^_@&B!;/F
MU@$;5H8!L^?'`;/U50#1CLV/(SC8_B,\^/[CDV/Z?583`P<@`9(\=P,X!P0,
M:Q1CL\<'`:V/M8^3EA<`_8/5C_&/7.,A!^,09_Z#/P4``S@%`0,SA0$B;P,^
MA0"#/@4"MX:"6I.&EIF3U[\!$Y=?`%V/-I^S16@`=I]QC[/UQ0%ZE[/%90"3
M$NX!+I>35RX`LW7'`+/G\@!"9[/RQP"3T[4!,T]8`!.950`3U"\`,W__`3:7
MDY3O`3-I>0#B8\&,&I<S3P\!.I^ECP5'>IGMC[:3%A<!%Y,960"SQU<`PI,;
M5+D!L_GI`!.?Y0&>EXF!@G,S;[\`L^F)`#-YR0#.E[/%Y`&VD_&,L_4E`1.4
M5P">DIO9MP&EC7F,EI63$^D!HG(362D`,V0T`;/C(P$NE+/YQP`3&50`LT=_
M`)M5M`$S?\\`L_<W`;:2,WGI`*:2L\?G`9.4Z0$S:;D`D]DI`,)UL^0T`9:7
M<8P^F;/'DP#AC[/SPP"VE?J5DQ)9`+/'=P";6;D!KI>S\N(`XG43'^0!"8`S
M;X\`L^(R`3-YR0"^DK/'Y`&S]R<!\8RVE9Z5$Y12`*6/F]FR`:Z7>8R&99,3
MZ0$362D`L^,C`3-D-`&S\L(`/I2S1W\`L_=7`#-_SP"VE::5$QE4`+/'YP&;
M6;0!KI<S>>D`IF63E.(!D](B`+/D5``S:3D!<8P^F;/'DP#AC[/SPP"VE?J5
MDQ)9`+/'=P";6;D!KI>S\N(`QF43'^0!"8`S;X\`L^(R`3-YR0"^DK/'Y`&S
M]R<!\8RVE9Z5$Y12`*6/F]FR`:Z7>8SF99,3Z0$362D`L^,C`3-D-`&S\L(`
M/I2S1W\`L_=7`#-_SP"VE::5DQE4`+/'YP&;5+0!KI>S^>D`AG43F>(!D](B
M`#-I60"SZ9D`<8R^F;/'(P'AC[/SPP"VE?J5DY)9`+/'=P";U+D!KI>S\N(`
MIG43'^0!"8`S;X\`L^*2`+Z2L_G)`+-'Z0&S]S<!,WG)`+:5GI63E%(`L\<G
M`1O:L@&NE_F,QG63D^D!D]DI`+/C,P&SY$0!,_3"`+Z4LT=_`.&/,W_/`+:5
MRI63F50`L\?G`1O9M`&NE[/YZ0#F=9,2Y`$)@+/B@@"SZ2D!\8R^F;/'4P`S
M],,`Y8^VE1.960#ZE9O3N0&ACS-YZ0"NEQ.?Y`$S:7D`B8"*8S-OGP`^F;/Y
MR0"SQ^(!DQ59`+/RP@";5+D!L_<W`;:3^8VBD\6-L\=7`*ID$Y3I`9/9*0`S
M9#0!GI<S><D`KI>S18\`L_4E`3-_SP"VE):4DY-7`+/%Y0&;V;<!II6S\^,`
MRF23$ND!$UDI`+/B(@&SXS,!\8^ND[-%5`"VE'&,_8T3F5,`)I^AC9O4LP$S
M>>D`^I4S:9D`$Y_G`>IDB8,S;_\`+IFS\\,`L\7B`;:4L_+"`),760"S]74`
MFUFY`2:4^8^SQ54`L^<W`:*5$Y3C`9/3(P`S9'0`\8^*<[Z5L_G%`#-YR0"S
M1X\`GI8S?\\`D].Y`;/W)P&3E%D`MI*SQ^<!L^1T`):7\8RJ<I,3Z0$362D`
ML^,C`;Z4M_;9;I.&%KHS^<0`LT=T`!-:N0&MC[:2DQ59`/J2\8\S[T4!EI<S
M?\\`/I^3DND!RG>3V2D`L^(R`;/%4P"S><\`<8RMC!/:N0&VEY.560"BE[/E
M10$S],0`HI?QC;Z5$Q3I`>IW$UDI`#-D)`&SQ((`,_G%`#/ZPP"VE[/#Y`&3
M5+D!$Q]9`+/SPP#2ES-OGP">ES-_SP`^GY.3Z0&.9Y/9*0"SXS,!LW3/`+-)
M=``S^L(`MI>SPKD`D]FT`9.55`"S\L(`TI>SY34!EI?QC;Z5DQ+I`:YG$UDI
M`+/B(@&SR5,`,_G%`#-ZQ`"VES/$Z0&36;D!$Q]9`'&,TI<S;S\!HI<S?\\`
M/I\3E.0!SF>)@$6,L\F"`+-TSP`S^L,`MI>SP[D`D]FT`9.55`"S\\,`TI>S
MY34!GI?QC;Z5DQ/I`>YG$UDI`+/C(P&S270`,_G%`#/ZP@"VE[/"Z0&36;D!
M$Q]9`+/RP@#2ES-O/P&6ES-_SP`^GY.2Y`&.=XF`L^*2`+/)4P"S=,\`,WK$
M`+:7,\2Y`)/9M`&3E50`<8S2E[/E-0&BE_&-OI43%.D!KG<362D`,V0D`;/)
M@@`S^<4`,_K#`+:7L\/I`9-9N0$3'UD`L_/#`-*7,V\_`9Z7,W_/`#Z?DY/D
M`<YWB8"SXY,`LTET`+-TSP`S^L(`MI>SPKD`D]FT`9.55`"S\L(`TI>SY34!
MEI?QC;Z5DQ+I`>YW$UDI`+/B(@&SR5,`,_G%`#-ZQ`"VES/$Z0&36;D!$Q]9
M`'&,TI<S;S\!HI<S?\\`/I\3E.0!DF>)@$6,L\F"`+-TSP`S^L,`MI>SP[D`
MD]FT`9.55`"S\\,`TI>SY34!GI?QC;Z5DQ/I`;)G$UDI`+/C(P&S270`,_G%
M`#/ZP@"VE[/"Z0&36;D!$Q]9`+/RP@#2ES-O/P&6ES-_SP`^GY.2Y`'29XF`
ML^*2`+-YSP"SQ%,`,WK$`+:7,\2T`)/4N0&3E5D`<8S2E\6-HI?QC;Z5DQ3I
M`?)G$UDI`+/D)`$SQ)(`,_G%`#/ZPP"VE[-#Y`$35+D!$Q]9`+/SPP#2ES-O
MCP">ES-_SP`^GQ.4Z0&2=Y/9*0`S9#0!L\.$`+-YSP"S\L(`$]JY`;:7L\6S
M`).360#QC9:7L^-#`:Z7L_/#`+)UDQ+I`1-9*0"SXB(!OI,S^<,`LT=4`/&,
M$UJY`;:5L\?G`1,?60#QCS-O3P&FE;Z5,W;/`#./Q0"3E.D!4G:3V2D`L^0T
M`?U7@9.SQ9(`LWG_`'V,-I:SQ74`$]JY`?V-DY-9`"*6+I:SXT,!\G43%.D!
M$UDI`#-D)`&S\_,`LI,SQH0`,_GS`+/R\@"VE3-/Y@$S?_\`$UJY`9:5DQ)9
M`/J5$Y;I`3/O0@&3V2D`EF(S9C8!+I^S1<0`_8RVDK/&=0#]CJ:2$QI?`+9D
MDQ7I`;:2$UDI`+?VQB.SY24!FU._`3-ZZ@"*!I.&QLVS>?8`,W__`#-J>@!-
MCK/S]0#2DC-Y]``S^GD`,W;F`;:4RI03E%(`,V9&`1O9L@$3&N\!)I9YC-9D
M$U\O`#-OZ@$S9"0!,_KR`#*4LW+_`+/EY0$S]E,`L_5%`;:4$QE4`,Z4T8V;
M6;0!,WGI`*:5,VDY`2Z9$Q;J`?9E$UHJ`#-F1@&S=/8`?8PS;\\`,_J2`+:5
M,W^/`),960"NDS-O3P&S^>D`&UJY`1Z?L^E)`?J9DQ7D`19_"8#!C;/S]0`S
M>?D`38XS^G0`-I\S=B8!$Y19`/J2,V9&`7F,&]JY`1:6,V1$`3*4$Q_I`39V
M$UDI`#-O+P&S<O\`L_GY`+/EY0$S^E,`-I:S]34!$QE4`+*4L^5%`3-YZ0`;
M6K0!II4S:4D!+ID3END!UG63V2D`,V8V`;-T]@!]C#-OSP`S^I(`MI4S?X\`
MDQE9`*Z3,V]/`;/YZ0`;6KD!'I^SZ4D!^IF3%>0!=G\)@,&-L_/U`#-Y^0!-
MCC/Z=``VGS-V)@$3E%D`^I(S9D8!>8P;VKD!%I8S9$0!,I03'^D!&F8362D`
M,V\O`;-R_P"S^?D`L^7E`3/Z4P`VEK/U-0$3&50`LI2SY44!,WGI`!M:M`&F
ME3-I20$NF1.6Z0&Z99/9*0`S9C8!LW3V`'V,,V_/`#/ZD@"VE3-_CP"3&5D`
MKI,S;T\!L_GI`!M:N0$>G[/I20'ZF9,5Y`%:;PF`P8VS\_4`,WGY`$V.,_IT
M`#:?,W8F`1.460#ZDC-F1@%YC!O:N0$6EC-D1`$RE!,?Z0%Z9A-9*0`S;R\!
MLW+_`+/Y^0"SY>4!,_I3`#:6L_4U`1,95`"RE+/E10$S>>D`&UJT`::5,VE)
M`2Z9$Y;I`9IUD]DI`#-F-@&S=/8`?8PS;\\`,_J2`+:5,W^/`),960"NDS-O
M3P&S^>D`&UJY`1Z?L^E)`?J9DQ7D`3I_"8#!C;/S]0`S>?D`38XS^G0`-I\S
M=B8!$Y19`/J2,V9&`7F,&]JY`1:6,V1$`3*4$Q_I`5IV$UDI`#-O+P&S<O\`
ML_GY`+/EY0$S^E,`-I:S]34!$QE4`+*4L^5%`3-YZ0`;6K0!$Y;I`9/9*0`S
M9C8!II4S:4D!LWGV`'V,+IDS;\\`^G6S]#(!,W^/`!,:60`S;Y\`,WKJ`)M4
MN0&VE3-JF@">9*Z3DQ7D`0F`P8T>GU*?L_/U`#-Y^0!-CK:4,_IY`):4,W8F
M`1,47P"3$ND!$UDI`+/B(@$S9D8!/FD;6K\!>8PS9$0!)I8BEK/T\@`S>O\`
ML^55`#:9$Q16`#/_DP!.F;/U10&;6;8!>8PS9#0!L^7E`=YI$Q_J`1-:*@`S
M;T\!RI5]CJ*5L^+B`3-T_P`S^H0`$YE5`+/RP@"VF9Z9L^)"`;-SZ0`;V;4!
ML^,C`<Z2?FF3&>8!"8*>DK/IR0"S\_D`_8TS;S\!$Y92`+-Z=`!YCAO:L@$S
M?[\`-IDFF3-O7P&S9$8!_8P>>A.6Y0%*GXF!,VFV`":?LW3_`#/V\@"SY2D!
MLW+Y`/&-,_M3`#::DYE4`)/:M`%2E+/F90&SY5D!HI;]C;.)M@`3%.8!OG4)
M@K>VF#)1C(H&DX9F'3-&B0`S^OD`MI4S1N8!$UFZ`:Z3$Q]:`'V.'I8S;R\!
MDY/D`8F`L^.3`#-__P#>=#*?,WG_`+-%=`"VE+/%-0$3%ED`DUFY`::2_8TS
M9C8!?8Z6E;*5DQ3J`7YV$UHJ`+/D1`&S^?4`L\*3`'V,$]JY`3:6L\+B`1.?
M60"S\O(`(I8S;T\!%I8S?_\`,I\3%.D!`S8!(!-9*0`S9"0!L\*$`#-Y_P"S
M\_,`$UJY`3:6L\*R`),560"S\O(`'I:SY44!%I;]C;*5DY+I`0,V@2"3V2D`
ML^(R`;-#5`"S^?4`_8P3VKD!-I:SP^,!$Y]9`+/S\P`FEC-O3P$>EC-__P`R
MGY,3Z0$#-@$A$UDI`+/C(P&S=/\`,\ER`#-Z]``VEC-$N0`3V;0!DY54`'V,
M4I:SY24!(I;]C;*5$Y3I`0,V@2&3V2D`,V0T`3/Y]0"SR8,`,_KR`#:6L\+I
M`9-9N0$3'UD`L_+R`%*6,V\_`1:6,W__`#*?DY+D`0,V`2*)@+/BD@"S250`
MLW3_`#/Z\P`VEK/#N0"3V;0!DY54`+/S\P!2EK/E-0$>EOV-LI63$^D!`S:!
M(A-9*0"SXR,!L\ER`#/Y]0`S>O0`-I8SQ.D!DUFY`1,?60!]C%*6,V\_`2*6
M,W__`#*?$Y3D`0,V`2.)@$6,L\F#`+-T_P`S^O(`-I:SPKD`D]FT`9.55`"S
M\O(`4I:SY34!%I;]C;*5DQ+I`0,V@2,362D`L^(B`;-)5``S^?4`,_KS`#:6
ML\/I`9-9N0$3'UD`L_/S`%*6,V\_`1Z6,W__`#*?DY/D`0,V`22)@+/CDP"S
MR7(`LW3_`#-Z]``VEC/$N0"3V;0!DY54`'V,4I:SY34!(I;]C;*5$Q3I`0,V
M@20362D`,V0D`;/)@P`S^?4`,_KR`#:6L\+I`9-9N0$3'UD`L_+R`%*6,V\_
M`1:6,W__`#*?DY+D`0,V`26)@+/BD@"S250`LW3_`#/Z\P`VEK/#N0"3V;0!
MDY54`+/S\P!2EK/E-0$>EOV-LI63$^D!`S:!)1-9*0"SXR,!L\ER`#/Y]0`S
M>O0`-I8SQ.D!DUFY`1,?60!]C%*6,V\_`2*6,W__`#*?$Y3D`0,V`2:)@$6,
ML\F#`+-T_P`S^O(`-I:SPKD`D]FT`9.55`"S\O(`4I:SY34!%I;]C;*5DQ+I
M`0,V@28362D`L^(B`;/Y]0`S250`,_KS`#:6LT/I`1/9N0$3GUD`L_/S`%*6
M,V\O`1Z6,W__`#*?DY/D`0,V`2>)@+/CDP`S>?\`L\1R`'V,I8T36KD!-I:3
M%%D`(I:SY$0!,_3U`"*6_8RRE).5Z0$#-H$GD]DI`+/E-0&SR;,`,_3T`+/R
M\@`VEC//Z0$S?_\`%I:3&50`$UJT`7J6,^])`3*?`S8!*),2Z0$362D`L^(B
M`;*6,\95`+/S\P#^EK-/E@`3%E\`GI:S__\`>8Z;4[\!,X?V`;-F=@`VEWV/
MDQ;D`0F`&.$SYX8`KIZ#/X$HLP;/`4*7,X9B`(.U"`#]CGV/?8ZS]_X`%.48
MZ1#M'/%CE;\"@S"!+`,T`2R#-($K`SD!*X,Y@2H#.@$J@SJ!*0,[`2D3`0$M
M@H#OT$^S01$3!0`(!N3OT(^CMW9=3(8&DX;FSS=WZ6$W)D5G%.D3!A8PMU8R
M$`8'$.&3AF9'%T8```,VAA83!P<?$.44[1CQ(S0%`B,X!0(C+`4&HF!!`8*`
M.7$B^";T2O!6Y`;\3NQ2Z!AUDQ<V`!1YNI>"%X&3,[?G`*J$NI8H71-7U@$V
MEYSTF/@RB2Z$DXJ$`SGMDP?P`V/;)PD;"0G\FUEI`(4)F@D;6FD`HIFBA1,&
M``16A>_0[ZT3!`0$)H7OX'_&XQ4T_QL::@`["4E!2H;.A5:%[]#OJR.L)`?B
M<$)THG0">>)I0FJB:B%A@H"3!P`$.X>G0+*)8TC'`AN*"0!2AJ*%5I7OT,^H
MO%P3!P`$NX8W`;3<XY/F_":%.PDY05*4[^`_P+6WNHG)OZ*)1;<Y<2+X)O1*
M\$[L6N`&_%+H5N2#UX4"`]<%`P.ZA0(3V8<`DUF'`!-6.@`3=O8#$XN%`Q-Y
M^0^3^?D/FY>'`!L7AP`NA+/G)P&S!<L`,V<W`1,(`/B3!A8`@SH$`Q.9!P,C
M@`4!DQD'`Y,%@`.JA!-9"0.3V0D#!28S!=L`8]#5$),'``0[AL=`@47OT(^_
M(H7OX%^V$P:``X%%6H7OT&^^DU>*`1/7B@$36@H!D]H*`2*%HPA4!R,9-`<C
M"O0&HPI$!R,;)`<C".0&[^"_LAQ@(H7A@R.`]``<8,&#HX#T`!Q@H8,C@?0`
M'&"C@?0`'&3A@R."]``<9,&#HX+T`!QDH8,C@_0`'&2C@_0`'&CA@R.$]``<
M:,&#HX3T`!QHH8,CA?0`'&BCA?0`'&SA@R.&]``<;,&#HX;T`!QLH8,CA_0`
M'&RCA_0`''#A@R.(]``<<,&#HXCT`!QPH8,CB?0`''"CB?0`0G3B<*)T`GGB
M:4)JHFH":R%A;]"OL9,'@`,[AL=`@47OT,^O&;\Y<2+X2O`75```$P0$&1=9
M```3"0D9,PF)0`;\)O1.[%+H5N0363E`8P\)`*J)+HJRBH%$'&!6AM*%3H6%
M!(*7(03C&9G^XG!"=*)T`GGB:4)JHFHA88*`@H"75@``@[;&-F_03Z$!``(`
M`````%!!4E]435!$25(```````!435!$25(``%1%35!$25(`5$5-4`````!4
M35```````"X`````````+BX````````E<R\E<P```"]P<F]C+W-E;&8O97AE
M``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````%!!4E]414U0
M``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E
M<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%
M4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%
M04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?
M1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,
M14%./0```````#$`````````3$1?3$E"4D%265]0051(`%5315(`````4UE3
M5$5-```O=&UP`````%5315).04U%```````````E,#)X`````'!A<BT`````
M)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E
M<R5S=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````<&5R;```
M```P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4P````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^
M)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE
M(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H
M=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]
M("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I
M>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK
M7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@
M)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S
M=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA
M9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N
M<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@
M)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W
M-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]
M(%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L
M97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L
M("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z
M("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H
M4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN
M97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(
M12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN
M="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@
M96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD
M=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E
M860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F
M(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I
M9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T
M('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M``!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````(FKS>\``````1L#.Q0````!````U)7__RP`````````
M$``````````#>E(``7P!`1L-`@`0````&````*"5__\N``````<!````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````!``````````$``````````0````````"M`0````````$`````````
M_`$````````!`````````$(#````````(`````````#(G0```````"$`````
M````"``````````9`````````-"=````````&P`````````(`````````!H`
M````````V)T````````<``````````@`````````]?[_;P````"@`@``````
M``4`````````@`T````````&`````````)`#````````"@``````````!0``
M``````L`````````&``````````5`````````````````````P````````!(
MH`````````(`````````H`4````````4``````````<`````````%P``````
M``#(%0````````<`````````N!,````````(`````````+`'````````"0``
M```````8`````````!X`````````"`````````#[__]O``````$```@`````
M_O__;P````!8$P```````/___V\``````P````````#P__]O`````(`2````
M````^?__;P`````+````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_____````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````'`;````````<!L```````!P&P```````'`;````````<!L`````
M``!P&P```````'`;````````<!L```````!P&P```````'`;````````<!L`
M``````!P&P```````'`;````````<!L```````!P&P```````'`;````````
M<!L```````!P&P```````'`;````````<!L```````!P&P```````'`;````
M````<!L```````!P&P```````'`;````````<!L```````!P&P```````'`;
M````````<!L```````!P&P```````'`;````````<!L```````!P&P``````
M`'`;````````<!L```````!P&P```````'`;````````<!L```````!P&P``
M`````'`;````````<!L```````!P&P```````'`;````````<!L```````!P
M&P```````'`;````````<!L```````!P&P```````'`;````````<!L`````
M``!P&P```````'`;````````<!L```````!P&P```````'`;````````<!L`
M``````!P&P```````'`;````````<!L```````!P&P```````."=````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1T-#.B`H56)U;G1U(#DN,RXP+3$S=6)U;G1U,2D@.2XS+C```"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM
M=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N9V]T`"YB<W,`
M+F-O;6UE;G0`````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````.`(````````X`@```````"$````````````````````!````````
M````````````$P````<````"`````````%P"````````7`(````````D````
M````````````````!````````````````````"8````'`````@````````"`
M`@```````(`"````````(`````````````````````0`````````````````
M```T````]O__;P(`````````H`(```````"@`@```````/``````````!0``
M```````(````````````````````/@````L````"`````````)`#````````
MD`,```````#P"0````````8````"````"``````````8`````````$8````#
M`````@````````"`#0```````(`-``````````4```````````````````$`
M``````````````````!.````____;P(`````````@!(```````"`$@``````
M`-0`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````%@3````````6!,```````!@``````````8````#````"```````````
M`````````&H````$`````@````````"X$P```````+@3````````$`(`````
M```%``````````@`````````&`````````!T````!````$(`````````R!4`
M``````#(%0```````*`%````````!0```!4````(`````````!@`````````
M>0````$````&`````````'`;````````<!L```````#@`P``````````````
M````$``````````0`````````'X````!````!@````````!0'P```````%`?
M````````4"T```````````````````0```````````````````"$`````0``
M``(`````````H$P```````"@3````````(`^```````````````````(````
M````````````````C`````$````"`````````""+````````((L````````4
M````````````````````!````````````````````)H````!`````@``````
M```XBP```````#B+````````+`````````````````````@`````````````
M``````"D````$`````,`````````R)T```````#(C0````````@`````````
M```````````!``````````@`````````LP````X````#`````````-"=````
M````T(T````````(````````````````````"``````````(`````````+\`
M```/`````P````````#8G0```````-B-````````"```````````````````
M``@`````````"`````````#+````!@````,`````````X)T```````#@C0``
M`````"`"````````!@`````````(`````````!``````````U`````$````#
M``````````"@`````````)````````!(````````````````````"```````
M`````````````-H````!`````P````````!(H````````$B0````````6`(`
M``````````````````@`````````"`````````#?````"`````,`````````
MH*(```````"@D@```````"@0```````````````````(````````````````
M````Y`````$````P````````````````````H)(````````D````````````
M`````````0`````````!``````````$````#````````````````````````
I`,22````````[0````````````````````$`````````````````````
